library global;

import 'package:flutter/material.dart';

export 'package:android_path_provider/android_path_provider.dart';
export 'package:device_info_plus/device_info_plus.dart';
export 'package:flutter_downloader/flutter_downloader.dart';
export 'package:flutter_inappwebview/flutter_inappwebview.dart';
export 'package:flutter_svg/flutter_svg.dart';
export 'package:fluttertoast/fluttertoast.dart';
export 'package:http/http.dart';
export 'package:intl/intl.dart';
export 'package:path_provider/path_provider.dart';
export 'package:permission_handler/permission_handler.dart';
export 'package:url_launcher/url_launcher.dart';

export './src/GColors.dart';
export './src/GDateFormats.dart';
export './src/GHttpReqs.dart';
export './src/GKeys.dart';
export './src/GPageTransition.dart';
export './src/GRefreshingWidget.dart';
export './src/GRegExpMatchers.dart';
export './src/GTextInputFormatters.dart';
export './src/GTexts.dart';
export './src/GUtils.dart';
export './src/GValidators.dart';
export './src/GValues.dart';
export './src/dialogs/GDialog.dart';
export './src/dialogs/GSearchableTextFieldDialog.dart';
export './src/dialogs/GAlertDialog.dart';

class Global {
  static bool _initialized = false;
  static late Color _themeColor;
  static late TextStyle _defTFFEnabledStyle;
  static late TextStyle _defTFFDisabledStyle;
  static late TextStyle _defTFFHintOrLabelStyle;
  static late TextStyle _defTFFFloatingLabelStyle;
  static late TextStyle _defDialogHeaderStyle;
  static late TextStyle _defDialogContentStyle;
  static late TextStyle _defDialogButtonStyle;
  static late GlobalKey<NavigatorState> _navigatorKey;

  /// Initializes the plugin. This must be called before any other method.
  static initialize({
    required Color themeColor,
    required TextStyle defTFFEnabledStyle,
    required TextStyle defTFFDisabledStyle,
    required TextStyle defTFFHintOrLabelStyle,
    required TextStyle defTFFFloatingLabelStyle,
    required TextStyle defDialogHeaderStyle,
    required TextStyle defDialogContentStyle,
    required TextStyle defDialogButtonStyle,
    required GlobalKey<NavigatorState> navigatorKey,
  }) {
    assert(
      !_initialized,
      'Plugin \'global\' has already been initialized',
    );
    _themeColor = themeColor;

    /// We are initializing default TextsStyles like this, because trying to set one font as theme-font
    /// and then using [copyWith] method to create customized fonts doesn't give exact results.
    _defTFFEnabledStyle = defTFFEnabledStyle;
    _defTFFDisabledStyle = defTFFDisabledStyle;
    _defTFFHintOrLabelStyle = defTFFHintOrLabelStyle;
    _defTFFFloatingLabelStyle = defTFFFloatingLabelStyle;
    _defDialogHeaderStyle = defDialogHeaderStyle;
    _defDialogContentStyle = defDialogContentStyle;
    _defDialogButtonStyle = defDialogButtonStyle;
    _navigatorKey = navigatorKey;
    _initialized = true;
  }

  static Color get themeColor => _themeColor;

  static TextStyle get defTFFEnabledStyle => _defTFFEnabledStyle;

  static TextStyle get defTFFDisabledStyle => _defTFFDisabledStyle;

  static TextStyle get defTFFHintOrLabelStyle => _defTFFHintOrLabelStyle;

  static TextStyle get defTFFFloatingLabelStyle => _defTFFFloatingLabelStyle;

  static TextStyle get defDialogHeaderStyle => _defDialogHeaderStyle;

  static TextStyle get defDialogContentStyle => _defDialogContentStyle;

  static TextStyle get defDialogButtonStyle => _defDialogButtonStyle;

  static GlobalKey<NavigatorState> get navigatorKey => _navigatorKey;
}
